import logging

from sqlalchemy.exc import IntegrityError, SQLAlchemyError, DatabaseError

from utils.errors.database import DatabaseError, DuplicateEntryError, DatabaseConnectionError
from models import Member
from database.manager import DatabaseManager

logger = logging.getLogger(__name__)


def create_new_member(new_member: Member):
    try:
        with DatabaseManager.get_session() as session:
            session.add(new_member)
            session.commit()
    except IntegrityError as e:
        logger.warning("Data already exists")
        session.rollback()
        raise DuplicateEntryError("Data already exists in the database") from e
    except DatabaseError as e:
        session.rollback()
        logger.critical("Connection with database interrupted")
        raise DatabaseConnectionError(
            "Connection with database interrupted") from e
    except SQLAlchemyError as e:
        logger.error(f"An error occured when saving member: {e}")
        session.rollback()
        raise DatabaseError(
            "An error occured when creating a new member") from e


__all__ = ["create_new_member"]
